%define major 1
%define libname %mklibname lxc %{major}
%define develname %mklibname lxc -d
%define debugcflags	%nil
%define	debug_package	%nil

%define luaver 5.2
%define lualibdir %{_libdir}/lua/%{luaver}
%define luapkgdir %{_datadir}/lua/%{luaver}

%bcond_without	lua
%bcond_without	python3

Name:		lxc
Version:	1.1.5
Release:	1
Summary:	Linux Containers
URL:		http://lxc.sourceforge.net
Source0:	https://linuxcontainers.org/downloads/%{name}-%{version}.tar.gz
Group:		System/Kernel and hardware
License:	LGPLv2
Epoch:		1
Patch1:		rosa-template.patch
Patch2:		rosa-template-make.patch
Patch3:		python-api-build.patch
BuildRequires:	docbook-utils
BuildRequires:	kernel-headers
BuildRequires:	cap-devel
Buildrequires:	docbook2x

Buildrequires:	libsystemd-daemon-devel
Buildrequires:	doxygen
Buildrequires:	selinux-devel
Buildrequires:	seccomp-devel
Buildrequires:	cgmanager-devel

%if %{with lua}
Buildrequires:	lua-devel
%endif
%if %{with python3}
Buildrequires:	python3-devel
Requires:	python3
Requires:	python3-lxc
%endif
# needed for lxc-busybox
Suggests:	busybox
# needed for lxc-debian
Suggests:	dpkg
# needed for lxc-debian, lxc-ubuntu:
Suggests:	debootstrap rsync
# needed for lxc-sshd
Requires:	openssh-server
# bridge
Requires:	bridge-utils

Conflicts:	lxc-doc < 0.7.5
Obsoletes:	lxc-doc < 0.7.5

%description
The package "%{name}" provides the command lines to create and manage
containers.  It contains a full featured container with the isolation
/ virtualization of the pids, the ipc, the utsname, the mount points,
/proc, /sys, the network and it takes into account the control groups.
It is very light, flexible, and provides a set of tools around the
container like the monitoring with asynchronous events notification,
or the freeze of the container. This package is useful to create
Virtual Private Server, or to run isolated applications like bash or
sshd.

%package -n	%{libname}
Summary:	Library for LXC
Group:		System/Libraries

%description -n %{libname}
Library for the Linux Kernel Containers.

%package -n	%{develname}
Summary:	Development files for LXC
Group:		Development/C

%description -n %{develname}
Developement files for the Linux Kernel Containers.

%if %{with lua}
%package        -n lua-%{name}
Summary:        Lua binding for %{name}
Group:          System/Libraries
Requires:       lua-filesystem

%description    -n lua-%{name}
Linux Resource Containers provide process and resource isolation without the
overhead of full virtualization.

The lua-%{name} package contains the Lua binding for %{name}.
%endif

%if %{with python3}
%package        -n python3-%{name}
Summary:        Python binding for %{name}
Group:          System/Libraries

%description    -n python3-%{name}
Linux Resource Containers provide process and resource isolation without the
overhead of full virtualization.

The python3-%{name} package contains the Python3 binding for %{name}.
%endif

%prep
%setup -q
%apply_patches

%build
autoreconf -fi
export LDFLAGS="$LDFLAGS -llua"
%configure2_5x  F77=no \
		--disable-apparmor \
		--with-distro=mandriva \
		--with-init-script=systemd \
		--enable-doc \
		--enable-api-docs \
		--enable-selinux \
		--enable-seccomp \
		--enable-capabilities \
		--enable-cgmanager \
		--enable-examples \
		--enable-bash \
		--with-systemdsystemunitdir=%{_unitdir} \
%if %{with lua}
		--enable-lua \
%else
		--disable-lua \
%endif
%if %{with python3}
		--enable-python \
%else
		--disable-python \
%endif

# remove rpath ( rpmlint error )
#sed -i '/AM_LDFLAGS = -Wl,-E -Wl,-rpath -Wl,$(libdir)/d' src/lxc/Makefile.in
%make

%install
%makeinstall_std templatesdir=%{_datadir}/lxc/templates READMEdir=%{_libexecdir}/lxc/rootfs

mkdir -p %{buildroot}/var/lib/%{name}

rm -f %{buildroot}%{_datadir}/%{name}/%{name}-patch.py*

# These doc files are empty:
rm -f %{buildroot}%{_docdir}/%{name}/{NEWS,ChangeLog}

%files
%doc README MAINTAINERS AUTHORS CONTRIBUTING COPYING
%{_datadir}/%{name}/config/common.conf.d/README
%{_datadir}/%{name}/config/common.seccomp
%{_datadir}/%{name}/selinux/lxc.if
%{_datadir}/%{name}/selinux/lxc.te
%{_sysconfdir}/lxc/default.conf
%{_sysconfdir}/default/lxc
%{_sysconfdir}/bash_completion.d/lxc
%{_bindir}/lxc-*
%{_datadir}/%{name}/%{name}.functions
%{_datadir}/%{name}/config/*.conf
%{_datadir}/lxc/hooks/*
%{_datadir}/lxc/templates/*
%{_libexecdir}/lxc/rootfs/README
%{_libexecdir}/lxc/lxc-*
%{_localstatedir}/lib/%{name}
%{_mandir}/ja/man*/%{name}*
%{_mandir}/man*/%{name}*
%{_sbindir}/init.lxc
%{_unitdir}/*

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{major}
%{_libdir}/lib%{name}.so.%{major}.*

%files -n %{develname}
%doc COPYING
%{_includedir}/%{name}/*.h
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%if %{with lua}
%files -n lua-%{name}
%{lualibdir}/%{name}
%{luapkgdir}/%{name}.lua
%endif

%if %{with python3}
%files -n python3-%{name}
%{python3_sitearch}/*
%endif

%changelog

* Sat Jan 30 2016 Denis Silakov <dsilakov@gmail.com> 1:1.1.5-1
- (ca15ebb) Updated to 1.1.5


